abacusai.llm_parameters — AbacusAI documentation

# `abacusai.llm_parameters`

## Module Contents

### Classes

`LlmParameters` | The parameters of LLM for given inputs.

class abacusai.llm_parameters.LlmParameters(client, parameters=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The parameters of LLM for given inputs.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - parameters (dict) – The parameters of LLM for given inputs.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict